@@ -9,12 +9,24 @@ See http://toscawidgets.org/documentation/WidgetBrowser for more information
 import widgets
 
 
-class DemoCodeMirrorWidget(widgets.CodeMirrorWidget):
+class DemoCodeMirrorEditor(widgets.CodeMirrorEditor):
     # Provide default parameters, value, etc... here
     # default = <some-default-value>
     mode = 'python'
+    fullscreen = True
     value = u'''
 def hello():
     print u'Hello World!'
     return True
-'''
\ No newline at end of file
+'''
+
+class DemoCodeMirrorDisplay(widgets.CodeMirrorDisplay):
+    # Provide default parameters, value, etc... here
+    # default = <some-default-value>
+    mode = 'python'
+    lineNumbers = False
+    value = u'''
+def hello():
+    print u'Hello World!'
+    return True
+'''
